@@ -8,10 +8,11 @@ from git_plan.cli.commands.command import Command
 from git_plan.exceptions import CommitAbandoned
 from git_plan.service.git import GitService
 from git_plan.service.plan import PlanService
-from git_plan.util.decorators import requires_initialized
+from git_plan.util.decorators import requires_initialized, requires_git_repository
 
 
 @requires_initialized
+@requires_git_repository
 class Commit(Command):
     """Commit a planned commit"""
 
@@ -26,7 +27,7 @@ class Commit(Command):
 
     def command(self, **kwargs):
         """Create a new commit"""
-        commits = self._plan_service.get_commits(self._project)
+        commits = self._plan_service.get_commits(self._repository)
         if not commits:
             print("No commits planned.")
             return
