@@ -12,12 +12,12 @@ class CommandNotFound(GitPlanException):
     """Command doesn't exist"""
 
 
-class ProjectNotInitialized(GitPlanException):
-    """The project was not initialized"""
+class NotInitialized(GitPlanException):
+    """The repo was not initialized"""
 
 
-class ProjectAlreadyInitialized(GitPlanException):
-    """The project is already initialized"""
+class AlreadyInitialized(GitPlanException):
+    """The repo is already initialized"""
 
 
 class CommitAbandoned(GitPlanException):
@@ -27,9 +27,10 @@ class CommitAbandoned(GitPlanException):
 class PlanEmpty(GitPlanException):
     """The commit plan was empty"""
 
+
 class GitException(GitPlanException):
     """Base class for git-related exceptions"""
 
 
 class NotAGitRepository(GitException):
-    """The current project is not a git repository"""
+    """The current repo is not a git repository"""
